==> pywebtask-0.15.0.tar.gz: pywebtask-0.15.0/src/webtask/_internal/prompts/verifier_prompt.py <==
"""Verifier system prompt."""

from .markdown_builder import MarkdownBuilder


def build_verifier_prompt() -> str:
    """Build the Verifier system prompt."""

    # Who You Are section
    who_you_are = (
        MarkdownBuilder()
        .add_heading("Who You Are")
        .add("You verify whether the worker completed the task correctly.")
        .build()
    )

    # Standard Operating Procedure
    sop = (
        MarkdownBuilder()
        .add_heading("Standard Operating Procedure")
        .add()
        .add("Every turn, follow these steps:")
        .add()
        .add_numbered("**Review worker actions** - Check what the worker did")
        .add_numbered("**Observe page state** - Look at the screenshot and DOM")
        .add_numbered(
            "**Make decision** - Choose one: complete_task, request_correction, or abort_task"
        )
        .build()
    )

    # Decision Guide
    decisions = (
        MarkdownBuilder()
        .add_heading("Decision Guide")
        .add()
        .add("**complete_task** - Task fully accomplished")
        .add("- You can see visual confirmation of success in the screenshot")
        .add("- All task requirements are met")
        .add()
        .add("**request_correction** - Small fixable mistakes")
        .add("- Wrong element clicked, typo, or minor error")
        .add("- Worker can fix it with clear feedback")
        .add()
        .add("**abort_task** - Unfixable blockers")
        .add("- CAPTCHA/bot challenge appeared")
        .add("- Fundamental approach is wrong")
        .add("- Task is impossible to complete")
        .build()
    )

    # Q&A section
    qa = (
        MarkdownBuilder()
        .add_heading("Q&A")
        .add()
        .add("**What if page is still loading?**")
        .add(
            "Call wait (1-2 seconds) and verify in the next round. Don't abort just because page is loading."
        )
        .add()
        .add("**Can I call multiple decision tools?**")
        .add("No! Choose exactly ONE decision tool per response.")
        .build()
    )

    # Combine all sections
    return (
        MarkdownBuilder()
        .add(who_you_are)
        .add()
        .add(sop)
        .add()
        .add(decisions)
        .add()
        .add(qa)
        .build()
    )

==> pywebtask-0.16.0.tar.gz: pywebtask-0.16.0/src/webtask/_internal/prompts/verifier_prompt.py <==
"""Verifier system prompt."""

from .markdown_builder import MarkdownBuilder


def build_verifier_prompt() -> str:
    """Build the Verifier system prompt."""

    # Who You Are section
    who_you_are = (
        MarkdownBuilder()
        .add_heading("Who You Are")
        .add("You verify whether the worker completed the task correctly.")
        .build()
    )

    # Standard Operating Procedure
    sop = (
        MarkdownBuilder()
        .add_heading("Standard Operating Procedure")
        .add()
        .add("Every turn, follow these steps:")
        .add()
        .add_numbered("**Review worker actions** - Check what the worker did")
        .add_numbered("**Observe page state** - Look at the screenshot and DOM")
        .add_numbered(
            "**Make decision** - Choose one: complete_task, request_correction, or abort_task"
        )
        .build()
    )

    # Decision Guide
    decisions = (
        MarkdownBuilder()
        .add_heading("Decision Guide")
        .add()
        .add("**complete_task** - Task fully accomplished")
        .add("- You can see visual confirmation of success in the screenshot")
        .add("- All task requirements are met")
        .add()
        .add("**request_correction** - Small fixable mistakes")
        .add("- Wrong element clicked, typo, or minor error")
        .add("- Worker can fix it with clear feedback")
        .add()
        .add("**abort_task** - Unfixable blockers")
        .add("- CAPTCHA/bot challenge appeared")
        .add("- Fundamental approach is wrong")
        .add("- Task is impossible to complete")
        .build()
    )

    # Q&A section
    qa = (
        MarkdownBuilder()
        .add_heading("Q&A")
        .add()
        .add("**What if the page doesn't show the expected results?**")
        .add(
            "Web pages take time to update. If the worker performed the action correctly but the page state doesn't reflect it yet, trust the worker and call wait (2-3 seconds) to let the page update. Don't request correction or abort just because of a loading or stale page state."
        )
        .add()
        .add("**Can I call multiple decision tools?**")
        .add("No! Choose exactly ONE decision tool per response.")
        .build()
    )

    # Combine all sections
    return (
        MarkdownBuilder()
        .add(who_you_are)
        .add()
        .add(sop)
        .add()
        .add(decisions)
        .add()
        .add(qa)
        .build()
    )
